@@ -1,5 +1,19 @@
 from bot.utilsbot import callback
-import bot.helptexts
+from bot.helptexts import (
+    welcomehelpp,
+    filterrhelp,
+    promotehelpp,
+    banhelpp,
+    kickhelpp,
+    pinhelpp,
+    purgehelpp,
+    notesshelp,
+    lockktypes,
+    lockhelpp,
+    fedhelpp,
+)
+from telethon import events, functions, Button
+import bot.utilsbot
 
 @callback("banhelp")
 async def _(event):
